.. image:: https://readthedocs.org/projects/bgwas3/badge/?version=latest
   :target: https://bgwas3.readthedocs.io/en/latest/

.. image:: https://travis-ci.com/g-r-eg/bgwas3.svg?branch=master
   :target: https://travis-ci.com/g-r-eg/bgwas3

======
bgwas3
======
